@@ -25,7 +25,7 @@ public sealed class ResetMonitorSpecificScalingExtension implements BeforeEachCa
 
 	@Override
 	public void beforeEach(ExtensionContext context) throws Exception {
-		wasMonitorSpecificScalingActive = Win32DPIUtils.isMonitorSpecificScalingActive();
+		wasMonitorSpecificScalingActive = DPIUtil.isMonitorSpecificScalingActive();
 		Display.getDefault().dispose();
 	}
 
@@ -33,6 +33,7 @@ public sealed class ResetMonitorSpecificScalingExtension implements BeforeEachCa
 	public void afterEach(ExtensionContext context) throws Exception {
 		Win32DPIUtils.setMonitorSpecificScaling(wasMonitorSpecificScalingActive);
 		Display.getDefault().dispose();
+		DPIUtil.setDeviceZoom(100);
 	}
 
 }
