@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2022 IBM Corporation and others.
+ * Copyright (c) 2000, 2025 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -1019,7 +1019,7 @@ abstract class Tab {
 		if (isArray) {
 			typeNameString += "[]";
 		}
-		return ControlExample.getResourceString("Parameter_Info", new Object[] {typeNameString, info});
+		return ControlExample.getResourceString("Parameter_Info", typeNameString, info);
 	}
 
 	void getValue() {
