@@ -1,7 +1,7 @@
 #!/bin/bash -xe
 
 #*******************************************************************************
-# Copyright (c) 2025, 2025 IBM Hannes Wellmann and others.
+# Copyright (c) 2025, 2025 Hannes Wellmann and others.
 #
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License 2.0
@@ -16,6 +16,7 @@
 
 # This script is called by the pipeline for preparing the next development cycle (this file's name is crucial!)
 # and applies the changes required individually for SWT.
+# The calling pipeline also defines environment variables usable in this script.
 
 make_common_mak='bundles/org.eclipse.swt/Eclipse SWT/common/library/make_common.mak'
 source "${make_common_mak}"
@@ -23,11 +24,13 @@ new_min_ver=$((min_ver + 1))
 
 sed -i "${make_common_mak}" \
 	--expression "s|min_ver=${min_ver}|min_ver=${new_min_ver}|g" \
-	--expression "s|rev=[0-9]\+|rev=0|g"
+	--expression "s|rev=[0-9]\+|rev=0|g" \
+	--expression "s|2000, [0-9]\{4\}|2000, ${NEXT_RELEASE_YEAR}|g"
 
 sed -i 'bundles/org.eclipse.swt/Eclipse SWT PI/common/org/eclipse/swt/internal/Library.java' \
 	--expression "s|MINOR_VERSION = ${min_ver};|MINOR_VERSION = ${new_min_ver};|g" \
-	--expression "s|REVISION = [0-9]\+;|REVISION = 0;|g"
+	--expression "s|REVISION = [0-9]\+;|REVISION = 0;|g"\
+	--expression "s|2000, [0-9]\{4\}|2000, ${NEXT_RELEASE_YEAR}|g"
 
 echo "version ${maj_ver}.${new_min_ver}" > 'bundles/org.eclipse.swt/Eclipse SWT/common/version.txt'
 
