@@ -109,6 +109,11 @@ public class Test_org_eclipse_swt_events_KeyEvent extends KeyboardLayoutTest {
 						return true;
 				}
 				break;
+			case PrtScr:
+				switch (state) {
+					case ____: // Opens snipping tool
+						return true;
+				}
 			case F4:
 				switch (state) {
 					case A___:  // Closes current Shell
