@@ -14,10 +14,8 @@
  *******************************************************************************/
 package org.eclipse.swt.tests.junit;
 
+import static org.eclipse.swt.internal.DPIUtil.pointToPixel;
 import static org.eclipse.swt.tests.junit.SwtTestUtil.assertSWTProblem;
-import static org.hamcrest.MatcherAssert.assertThat;
-import static org.hamcrest.Matchers.is;
-import static org.hamcrest.Matchers.not;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
@@ -29,6 +27,8 @@ import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assumptions.assumeFalse;
 import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
+import java.lang.ref.WeakReference;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 
 import org.eclipse.swt.SWT;
@@ -38,6 +38,8 @@ import org.eclipse.swt.graphics.FontMetrics;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.ImageData;
+import org.eclipse.swt.graphics.ImageDataAtSizeProvider;
+import org.eclipse.swt.graphics.ImageDataProvider;
 import org.eclipse.swt.graphics.ImageGcDrawer;
 import org.eclipse.swt.graphics.LineAttributes;
 import org.eclipse.swt.graphics.PaletteData;
@@ -52,6 +54,8 @@ import org.eclipse.swt.widgets.Shell;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
+import org.junit.jupiter.params.ParameterizedTest;
+import org.junit.jupiter.params.provider.ValueSource;
 
 /**
  * Automated Test Suite for class org.eclipse.swt.graphics.GC
@@ -246,6 +250,60 @@ public void test_dispose() {
 	gc.dispose();
 }
 
+
+@Test
+public void test_drawImage_nonAutoScalableGC_bug_2504() throws InterruptedException {
+	Shell shell = new Shell(display);
+    float targetScale = 2f;
+    int srcSize = 50;
+    Image image = new Image(display, srcSize, srcSize);
+    GC gcSrc = new GC(image);
+    gcSrc.setBackground(display.getSystemColor(SWT.COLOR_BLACK));
+    gcSrc.fillRectangle(0, 0, srcSize, srcSize);
+    gcSrc.setBackground(display.getSystemColor(SWT.COLOR_WHITE));
+    gcSrc.fillRectangle(2, 2, srcSize - 4, srcSize - 4);
+    gcSrc.dispose();
+
+    Rectangle bounds = image.getBounds();
+
+    Canvas canvas = new Canvas(shell, SWT.NONE) {
+        @Override
+        public boolean isAutoScalable() {
+            return false;
+        }
+    };
+
+    int canvasWidth = Math.round(bounds.width * targetScale);
+    int canvasHeight = Math.round(bounds.height * targetScale);
+    canvas.setSize(canvasWidth, canvasHeight);
+    AtomicBoolean paintListenerCalled = new AtomicBoolean();
+    canvas.addPaintListener(e -> {
+        e.gc.drawImage(image, 0, 0, bounds.width, bounds.height,
+                       0, 0, canvasWidth, canvasHeight);
+        paintListenerCalled.set(true);
+    });
+
+    shell.open();
+	int timeoutMillis = 2000;
+	SwtTestUtil.processEvents(timeoutMillis, () -> paintListenerCalled.get());
+	assertTrue(paintListenerCalled.get(), "paint listener was never called");
+	Image target = new Image(display, canvasWidth, canvasHeight);
+    GC gcCopy = new GC(canvas);
+    gcCopy.copyArea(target, 0, 0);
+    gcCopy.dispose();
+
+    ImageData data = target.getImageData();
+
+    int bottomRightX = canvasWidth - 1;
+    int bottomRightY = canvasHeight - 1;
+    RGB bottomRight = data.palette.getRGB(data.getPixel(bottomRightX, bottomRightY));
+    RGB black = new RGB(0, 0, 0);
+    assertEquals( black, bottomRight, "Bottom-right pixel is not black! when source GC is not autoScalable");
+	shell.dispose();
+    target.dispose();
+    image.dispose();
+}
+
 @Test
 public void test_drawArcIIIIII() {
 	gc.drawArc(10, 20, 50, 25, 90, 90);
@@ -256,12 +314,28 @@ public void test_drawFocusIIII() {
 	gc.drawFocus(1, 1, 50, 25);
 }
 
-@Test
-public void test_drawImageLorg_eclipse_swt_graphics_ImageII() {
+private static class TestImages {
+    final Image normal;
+    final Image transparent;
+    final Image alpha;
+
+    TestImages(Image normal, Image transparent, Image alpha) {
+        this.normal = normal;
+        this.transparent = transparent;
+        this.alpha = alpha;
+    }
+
+    void dispose() {
+        normal.dispose();
+        transparent.dispose();
+        alpha.dispose();
+    }
+}
+
+private TestImages createTestImages(Display display) {
 	Color c1 = new Color(255, 0, 0);
 	Color c2 = new Color(0, 0, 0);
 	Color c3 = new Color(255, 255, 0);
-
 	PaletteData paletteData = new PaletteData(c1.getRGB(), c2.getRGB(), c3.getRGB());
 	ImageData data = new ImageData(30,30, 8, paletteData);
 	for (int y = 0; y < data.height; y++) {
@@ -282,50 +356,173 @@ public void test_drawImageLorg_eclipse_swt_graphics_ImageII() {
 		}
 	}
 	Image imageAlpha = new Image(display, data);
+    c1.dispose();
+    c2.dispose();
+    c3.dispose();
+    return new TestImages(image, imageTransparent, imageAlpha);
+}
 
-	gc.drawImage(image, 100, 100);
-	gc.drawImage(imageTransparent, 130, 100);
-	gc.drawImage(imageAlpha, 160, 100);
+
+@Test
+public void test_drawImageLorg_eclipse_swt_graphics_ImageII() {
+	TestImages images = createTestImages(display);
+
+	gc.drawImage(images.normal, 100, 100);
+	gc.drawImage(images.transparent, 130, 100);
+	gc.drawImage(images.alpha, 160, 100);
 	assertThrows(IllegalArgumentException.class, () -> gc.drawImage(null, 100, 100));
-	image.dispose();
-	imageTransparent.dispose();
-	imageAlpha.dispose();
+	images.dispose();
 }
 
 @Test
 public void test_drawImageLorg_eclipse_swt_graphics_ImageIIIIIIII() {
-	Color c1 = new Color(255, 0, 0);
-	Color c2 = new Color(0, 0, 0);
-	Color c3 = new Color(255, 255, 0);
-
-	PaletteData paletteData = new PaletteData(c1.getRGB(), c2.getRGB(), c3.getRGB());
-	ImageData data = new ImageData(30,30, 8, paletteData);
-	for (int y = 0; y < data.height; y++) {
-		for (int x = 0; x < data.width; x++) {
-			if (x > y) data.setPixel(x, y, paletteData.getPixel(c1.getRGB()));
-			else if (x < y) data.setPixel(x, y, paletteData.getPixel(c2.getRGB()));
-			else data.setPixel(x, y, paletteData.getPixel(c3.getRGB()));
-		}
-	}
-	Image image = new Image(display, data);
-	data = image.getImageData();
-	data.transparentPixel = paletteData.getPixel(c1.getRGB());
-	Image imageTransparent = new Image(display, data);
-	data.transparentPixel = -1;
-	for (int y = 0; y < data.height; y++) {
-		for (int x = 0; x < data.width; x++) {
-			data.setAlpha(x, y, 127);
-		}
-	}
-	Image imageAlpha = new Image(display, data);
-
-	gc.drawImage(image, 10, 5, 20, 15, 100, 120, 50, 60);
-	gc.drawImage(imageTransparent, 10, 5, 20, 15, 100, 120, 10, 10);
-	gc.drawImage(imageAlpha, 10, 5, 20, 15, 100, 120, 20, 15);
+	TestImages images = createTestImages(display);
+	gc.drawImage(images.normal, 10, 5, 20, 15, 100, 120, 50, 60);
+	gc.drawImage(images.transparent, 10, 5, 20, 15, 100, 120, 10, 10);
+	gc.drawImage(images.alpha, 10, 5, 20, 15, 100, 120, 20, 15);
 	assertThrows(IllegalArgumentException.class, () -> gc.drawImage(null, 10, 5, 20, 15, 100, 120, 50, 60));
+	images.dispose();
+}
+
+
+@Test
+public void test_drawImageLorg_eclipse_swt_graphics_ImageIIII() {
+	TestImages images = createTestImages(display);
+	gc.drawImage(images.normal, 100, 120, 50, 60);
+	gc.drawImage(images.transparent, 100, 120, 10, 10);
+	gc.drawImage(images.alpha, 100, 120, 20, 15);
+	assertThrows(IllegalArgumentException.class, () -> gc.drawImage(null, 100, 120, 50, 60));
+	images.dispose();
+}
+
+@Test
+public void test_drawImageLorg_eclipse_swt_graphics_ImageIIII_ImageDataProvider() {
+	int width = 32;
+	int height = 48;
+	Image drawToImage = new Image(display, width, height);
+	GC gc = new GC(drawToImage);
+	gc.setAntialias(SWT.OFF);
+	RGB drawnRgb = new RGB(255, 255, 255);
+	RGB undrawnRgb = new RGB(0, 0, 0);
+	ImageDataProvider imageDataProvider = zoom -> {
+		if (zoom != 100) {
+			return null;
+		}
+		PaletteData palette = new PaletteData(0xFF0000, 0xFF00, 0xFF);
+		ImageData imageData = new ImageData(16, 16, 32, palette);
+		int drawnPixel = palette.getPixel(drawnRgb);
+		for (int i = 0; i < 16; i++) {
+			imageData.setPixel(i, 0, drawnPixel);
+			imageData.setPixel(i, 15, drawnPixel);
+			imageData.setPixel(0, i, drawnPixel);
+			imageData.setPixel(15, i, drawnPixel);
+		}
+		return imageData;
+	};
+	Image image = new Image(display, imageDataProvider);
+	try {
+		gc.drawImage(image, 0, 0, width, height);
+		int zoom = DPIUtil.getDeviceZoom();
+		ImageData printedImageData = drawToImage.getImageData(zoom);
+		PaletteData printedPalette = printedImageData.palette;
+		// Expect that image is blurry scaled to the desired extents
+		assertEquals(drawnRgb, printedPalette.getRGB(printedImageData.getPixel(0, 0)));
+		assertNotEquals(undrawnRgb, printedPalette.getRGB(printedImageData.getPixel(1, 1)));
+		assertNotEquals(undrawnRgb, printedPalette.getRGB(printedImageData.getPixel(1, 2)));
+		assertEquals(undrawnRgb, printedPalette.getRGB(printedImageData.getPixel(pointToPixel(width, zoom) / 2, pointToPixel(height, zoom) / 2)));
+		assertNotEquals(undrawnRgb, printedPalette.getRGB(printedImageData.getPixel(pointToPixel(width, zoom) - 2, pointToPixel(height, zoom) - 3)));
+		assertNotEquals(undrawnRgb, printedPalette.getRGB(printedImageData.getPixel(pointToPixel(width, zoom) - 2, pointToPixel(height, zoom) - 2)));
+		assertEquals(drawnRgb, printedPalette.getRGB(printedImageData.getPixel(pointToPixel(width, zoom) - 1, pointToPixel(height, zoom) - 1)));
+	} finally {
+		image.dispose();
+		drawToImage.dispose();
+	}
+}
+
+@Test
+public void test_drawImageLorg_eclipse_swt_graphics_ImageIIII_ImageDataAtSizeProvider_invalid() {
+	ImageDataAtSizeProvider provider = (width, height) -> null;
+	Image image = new Image(display, provider);
+	Image drawToImage = new Image(display, 1, 1);
+	try {
+		GC gc = new GC(drawToImage);
+		Exception e = assertThrows(IllegalArgumentException.class, () -> gc.drawImage(image, 0, 0, 1, 1));
+		assertSWTProblem("Incorrect exception thrown for provider == null", SWT.ERROR_INVALID_ARGUMENT, e);
+	} finally {
+		image.dispose();
+		drawToImage.dispose();
+	}
+}
+
+@ParameterizedTest
+@ValueSource(ints = {SWT.IMAGE_COPY, SWT.IMAGE_DISABLE, SWT.IMAGE_GRAY, -1})
+public void test_drawImageLorg_eclipse_swt_graphics_ImageIIII_ImageDataAtSizeProvider(int styleFlag) {
+	int width = 50;
+	int height = 70;
+	Image drawToImage = new Image(display, new ImageData(width, height, 32, new PaletteData(0xFF0000, 0xFF00, 0xFF)));
+	GC gc = new GC(drawToImage);
+	gc.setAntialias(SWT.OFF);
+	RGB drawnRgb = new RGB(255, 255, 255);
+	RGB undrawnRgb = new RGB(0, 0, 0);
+	ImageDataAtSizeProvider imageDataAtSizeProvider = (width1, height1) -> {
+		PaletteData palette = new PaletteData(0xFF0000, 0xFF00, 0xFF);
+		int drawnPixel = palette.getPixel(drawnRgb);
+		ImageData imageData = new ImageData(width1, height1, 32, palette);
+		for (int i = 0; i < width1; i++) {
+			imageData.setPixel(i, 0, drawnPixel);
+			imageData.setPixel(i, height1 - 1, drawnPixel);
+		}
+		for (int i = 0; i < height1; i++) {
+			imageData.setPixel(0, i, drawnPixel);
+			imageData.setPixel(width1 - 1, i, drawnPixel);
+		}
+		return imageData;
+	};
+	Image image = styleImage(new Image(display, imageDataAtSizeProvider), styleFlag);
+
+	try {
+		gc.drawImage(image, 0, 0, width, height);
+		int zoom = DPIUtil.getDeviceZoom();
+		ImageData printedImageData = drawToImage.getImageData(zoom);
+		PaletteData printedPalette = printedImageData.palette;
+		RGB styledDrawnRgb = getStyledRgb(drawnRgb, styleFlag);
+		RGB styledUndrawnRgb = getStyledRgb(undrawnRgb, styleFlag);
+		assertEquals(styledDrawnRgb, printedPalette.getRGB(printedImageData.getPixel(0, 0)));
+		assertEquals(styledUndrawnRgb, printedPalette.getRGB(printedImageData.getPixel(1, 1)));
+		assertEquals(styledUndrawnRgb, printedPalette.getRGB(printedImageData.getPixel(pointToPixel(width, zoom) / 2, pointToPixel(height, zoom) / 2)));
+		assertEquals(styledUndrawnRgb, printedPalette.getRGB(printedImageData.getPixel(pointToPixel(width, zoom) - 2, pointToPixel(height, zoom) - 2)));
+		assertEquals(styledDrawnRgb, printedPalette.getRGB(printedImageData.getPixel(pointToPixel(width, zoom) - 4, pointToPixel(height, zoom) - 1)));
+	} finally {
+		image.dispose();
+		drawToImage.dispose();
+	}
+}
+
+private Image styleImage(Image image, int styleFlag) {
+	if (styleFlag == -1) {
+		return image;
+	}
+	Image styledImage = new Image(display, image, styleFlag);
 	image.dispose();
-	imageAlpha.dispose();
-	imageTransparent.dispose();
+	return styledImage;
+}
+
+private RGB getStyledRgb(RGB rgb, int styleFlag) {
+	if (styleFlag == -1) {
+		return rgb;
+	}
+	PaletteData palette = new PaletteData(0xFF0000, 0xFF00, 0xFF);
+	ImageData referenceData = new ImageData(1, 1, 32, palette);
+	referenceData.setPixel(0, 0, palette.getPixel(rgb));
+	Image referenceImage = new Image(display, referenceData);
+	Image styledReferenceImage = new Image(display, referenceImage, styleFlag);
+	try {
+		ImageData styledmageData = styledReferenceImage.getImageData();
+		return styledmageData.palette.getRGB(styledmageData.getPixel(0, 0));
+	} finally {
+		styledReferenceImage.dispose();
+		referenceImage.dispose();
+	}
 }
 
 @Test
@@ -774,8 +971,8 @@ public void test_drawLine_noSingularitiesIn45DregreeRotation() {
 		gc.setTransform(rotation);
 		gc.drawLine(centerPixel, centerPixel, centerPixel + 1, centerPixel);
 
-		assertThat("line is not drawn with 45 degree rotation",
-				image.getImageData().getPixel(centerPixel, centerPixel), not(is(-1)));
+		assertNotEquals(-1,
+				image.getImageData().getPixel(centerPixel, centerPixel), "line is not drawn with 45 degree rotation");
 	} finally {
 		rotation.dispose();
 		gc.dispose();
@@ -804,6 +1001,28 @@ public void test_bug1288_createGCFromImageFromNonDisplayThread() throws Interrup
 	assertNull(exceptionReference.get(), "Creating a GC from an Image without a device threw an exception");
 }
 
+// Tests that a GC instance is cleaned from memory after it was disposed.
+// Primarily supposed to test that the operations (currently only implemented for Windows) do not produce any leaks.
+@Test
+public void test_noMemoryLeakAfterDispose() {
+	GC testGC = new GC(display);
+	Image image = new Image(display, 1, 1);
+	try {
+		testGC.setFont(display.getSystemFont());
+		testGC.setClipping(new Rectangle(0, 0, 2, 2));
+		testGC.drawImage(image, 0, 0);
+		testGC.drawText("Test", 0, 0);
+		testGC.drawLine(0, 0, 5, 5);
+		WeakReference<GC> testGCReference = new WeakReference<>(testGC);
+		testGC.dispose();
+		testGC = null;
+		System.gc();
+		assertNull(testGCReference.get());
+	} finally {
+		image.dispose();
+	}
+}
+
 /* custom */
 Display display;
 Shell shell;
