@@ -15,23 +15,23 @@
 package org.eclipse.swt.tests.junit;
 
 
+import static org.eclipse.swt.tests.graphics.ImageDataTestHelper.imageDataComparator;
 import static org.eclipse.swt.tests.junit.SwtTestUtil.assertSWTProblem;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThrows;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assume.assumeFalse;
-import static org.junit.Assume.assumeTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeFalse;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.nio.file.Files;
 import java.nio.file.Path;
-import java.util.Comparator;
 import java.util.List;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.Consumer;
@@ -42,18 +42,20 @@ import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.ImageData;
+import org.eclipse.swt.graphics.ImageDataAtSizeProvider;
 import org.eclipse.swt.graphics.ImageDataProvider;
 import org.eclipse.swt.graphics.ImageFileNameProvider;
 import org.eclipse.swt.graphics.ImageGcDrawer;
 import org.eclipse.swt.graphics.PaletteData;
+import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.RGB;
 import org.eclipse.swt.graphics.Rectangle;
 import org.eclipse.swt.internal.DPIUtil;
 import org.eclipse.swt.widgets.Display;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
+
 
 /**
  * Automated Test Suite for class org.eclipse.swt.graphics.Image
@@ -63,8 +65,8 @@ import org.junit.rules.TemporaryFolder;
 @SuppressWarnings("restriction")
 public class Test_org_eclipse_swt_graphics_Image {
 
-	@ClassRule
-	public static TemporaryFolder tempFolder = new TemporaryFolder();
+	@TempDir
+	static Path tempFolder;
 
 	private static String getPath(String fileName) {
 		return SwtTestUtil.getPath(fileName, tempFolder).toString();
@@ -96,7 +98,7 @@ public class Test_org_eclipse_swt_graphics_Image {
 	};
 ImageGcDrawer imageGcDrawer = (gc, width, height) -> {};
 
-@Before
+@BeforeEach
 public void setUp() {
 	display = Display.getDefault();
 }
@@ -431,6 +433,25 @@ public void test_ConstructorLorg_eclipse_swt_graphics_Device_ImageDataProvider()
 	image.dispose();
 }
 
+@Test
+public void test_ConstructorLorg_eclipse_swt_graphics_Device_ImageDataAtSizeProvider() {
+	int imageSize = 10;
+	ImageDataAtSizeProvider provider = new ImageDataAtSizeProvider() {
+		@Override
+		public Point getDefaultSize() {
+			return new Point(imageSize, imageSize);
+		}
+		@Override
+		public ImageData getImageData(int width, int height) {
+			return new ImageData(width, height, 32, new PaletteData(0xFF0000, 0xFF00, 0xFF));
+		}
+	};
+	Image image = new Image(display, provider);
+	assertEquals(imageSize, image.getBounds().width);
+	assertEquals(imageSize * 2, image.getImageData(200).width);
+	image.dispose();
+}
+
 @Test
 public void test_ConstructorLorg_eclipse_swt_graphics_Device_ImageGcDrawer() {
 	// Null provider
@@ -584,7 +605,6 @@ public void test_getBounds() {
 	image.dispose();
 	assertEquals(bounds, bounds1);
 }
-
 @SuppressWarnings("removal")
 @Test
 public void test_getBoundsInPixels() {
@@ -600,8 +620,8 @@ public void test_getBoundsInPixels() {
 	Rectangle boundsInPixels = image.getBoundsInPixels();
 	Rectangle bounds = image.getBounds();
 	image.dispose();
-	assertEquals("Image.getBounds method doesn't return original bounds.", initialBounds, bounds);
-	assertEquals("Image.getBoundsInPixels method doesn't return bounds in Pixel values.", initialBounds, boundsInPixels);
+	assertEquals(initialBounds, bounds);
+	assertEquals(initialBounds, boundsInPixels);
 
 	// create icon image
 	ImageData imageData = new ImageData(initialBounds.width, initialBounds.height, 1, new PaletteData(new RGB[] {new RGB(0, 0, 0)}));
@@ -609,30 +629,30 @@ public void test_getBoundsInPixels() {
 	boundsInPixels = image.getBoundsInPixels();
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals("Image.getBounds method doesn't return original bounds.", initialBounds, bounds);
-	assertEquals("Image.getBoundsInPixels method doesn't return bounds in Pixel values.", initialBounds, boundsInPixels);
+	assertEquals(initialBounds, bounds);
+	assertEquals(initialBounds, boundsInPixels);
 
 	// create image with FileNameProvider
 	image = new Image(display, imageFileNameProvider);
 	boundsInPixels = image.getBoundsInPixels();
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals("Image.getBoundsInPixels method doesn't return bounds in Pixel values.", bounds, boundsInPixels);
+	assertEquals(bounds, boundsInPixels);
 
 	// create image with ImageDataProvider
 	image = new Image(display, imageDataProvider);
 	boundsInPixels = image.getBoundsInPixels();
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals("Image.getBoundsInPixels method doesn't return bounds in Pixel values.", bounds, boundsInPixels);
+	assertEquals(bounds, boundsInPixels);
 
 	// create image with ImageGcDrawer
 	image = new Image(display, imageGcDrawer, initialBounds.width, initialBounds.height);
 	boundsInPixels = image.getBoundsInPixels();
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals("Image.getBounds method doesn't return original bounds.", initialBounds, bounds);
-	assertEquals("Image.getBoundsInPixels method doesn't return bounds in Pixel values for ImageGcDrawer.", initialBounds, boundsInPixels);
+	assertEquals(initialBounds, bounds);
+	assertEquals(initialBounds, boundsInPixels);
 }
 
 @SuppressWarnings("removal")
@@ -650,7 +670,7 @@ public void test_getImageDataCurrentZoom() {
 	ImageData imageDataAtCurrentZoom = image.getImageDataAtCurrentZoom();
 	image.dispose();
 	Rectangle boundsAtCurrentZoom = new Rectangle(0, 0, imageDataAtCurrentZoom.width, imageDataAtCurrentZoom.height);
-	assertEquals(":a: Size of ImageData returned from Image.getImageDataAtCurrentZoom method doesn't return matches with bounds in Pixel values.", boundsAtCurrentZoom, bounds);
+	assertEquals(boundsAtCurrentZoom, bounds);
 
 	// create icon image and compare size of imageData
 	ImageData imageData = new ImageData(bounds.width, bounds.height, 1, new PaletteData(new RGB[] {new RGB(0, 0, 0)}));
@@ -658,7 +678,7 @@ public void test_getImageDataCurrentZoom() {
 	imageDataAtCurrentZoom = image.getImageDataAtCurrentZoom();
 	image.dispose();
 	boundsAtCurrentZoom = new Rectangle(0, 0, imageDataAtCurrentZoom.width, imageDataAtCurrentZoom.height);
-	assertEquals(":b: Size of ImageData returned from Image.getImageDataAtCurrentZoom method doesn't return matches with bounds in Pixel values.", boundsAtCurrentZoom, bounds);
+	assertEquals(boundsAtCurrentZoom, bounds);
 
 	// create image with FileNameProvider
 	image = new Image(display, imageFileNameProvider);
@@ -666,7 +686,7 @@ public void test_getImageDataCurrentZoom() {
 	boundsAtCurrentZoom = new Rectangle(0, 0, imageDataAtCurrentZoom.width, imageDataAtCurrentZoom.height);
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals(":c: Size of ImageData returned from Image.getImageDataAtCurrentZoom method doesn't return matches with bounds in Pixel values.", boundsAtCurrentZoom, bounds);
+	assertEquals(boundsAtCurrentZoom, bounds);
 
 	// create image with ImageDataProvider
 	image = new Image(display, imageDataProvider);
@@ -674,14 +694,7 @@ public void test_getImageDataCurrentZoom() {
 	boundsAtCurrentZoom = new Rectangle(0, 0, imageDataAtCurrentZoom.width, imageDataAtCurrentZoom.height);
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals(":d: Size of ImageData returned from Image.getImageDataAtCurrentZoom method doesn't return matches with bounds in Pixel values.", boundsAtCurrentZoom, bounds);
-}
-
-@Test
-public void test_getImageData() {
-	getImageData1();
-	getImageData2(24, new PaletteData(0xff0000, 0xff00, 0xff));
-	getImageData2(32, new PaletteData(0xff0000, 0xff00, 0xff));
+	assertEquals(boundsAtCurrentZoom, bounds);
 }
 
 @Test
@@ -737,7 +750,7 @@ void getImageData_int(int zoom) {
 	ImageData imageDataAtZoom = image.getImageData(zoom);
 	image.dispose();
 	Rectangle boundsAtZoom = new Rectangle(0, 0, imageDataAtZoom.width, imageDataAtZoom.height);
-	assertEquals(":a: Size of ImageData returned from Image.getImageData(int) method doesn't return matches with bounds in Pixel values.", scaleBounds(bounds, zoom, 100), boundsAtZoom);
+	assertEquals(scaleBounds(bounds, zoom, 100), boundsAtZoom);
 
 	// creates second bitmap image and compare size of imageData
 	image = new Image(display, bounds.width, bounds.height);
@@ -745,14 +758,14 @@ void getImageData_int(int zoom) {
 	boundsAtZoom = new Rectangle(0, 0, imageDataAtZoom.width, imageDataAtZoom.height);
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals(":a: Size of ImageData returned from Image.getImageData(int) method doesn't return matches with bounds in Pixel values.", scaleBounds(bounds, zoom, 100), boundsAtZoom);
+	assertEquals(scaleBounds(bounds, zoom, 100), boundsAtZoom);
 
 	// creates bitmap image with GCDrawer and compare size of imageData
 	image = new Image(display, (gc, width, height) -> {}, bounds.width, bounds.height);
 	imageDataAtZoom = image.getImageData(zoom);
 	image.dispose();
 	boundsAtZoom = new Rectangle(0, 0, imageDataAtZoom.width, imageDataAtZoom.height);
-	assertEquals(":a: Size of ImageData returned from Image.getImageData(int) method doesn't return matches with bounds in Pixel values.", scaleBounds(bounds, zoom, 100), boundsAtZoom);
+	assertEquals(scaleBounds(bounds, zoom, 100), boundsAtZoom);
 
 	// create icon image and compare size of imageData
 	ImageData imageData = new ImageData(bounds.width, bounds.height, 1, new PaletteData(new RGB[] {new RGB(0, 0, 0)}));
@@ -760,7 +773,7 @@ void getImageData_int(int zoom) {
 	imageDataAtZoom = image.getImageData(zoom);
 	image.dispose();
 	boundsAtZoom = new Rectangle(0, 0, imageDataAtZoom.width, imageDataAtZoom.height);
-	assertEquals(":b: Size of ImageData returned from Image.getImageData(int) method doesn't return matches with bounds in Pixel values.", scaleBounds(bounds, zoom, 100), boundsAtZoom);
+	assertEquals(scaleBounds(bounds, zoom, 100), boundsAtZoom);
 
 	// create image with FileNameProvider
 	image = new Image(display, imageFileNameProvider);
@@ -768,7 +781,7 @@ void getImageData_int(int zoom) {
 	boundsAtZoom = new Rectangle(0, 0, imageDataAtZoom.width, imageDataAtZoom.height);
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals(":c: Size of ImageData returned from Image.getImageData(int) method doesn't return matches with bounds in Pixel values.", scaleBounds(bounds, zoom, 100), boundsAtZoom);
+	assertEquals(scaleBounds(bounds, zoom, 100), boundsAtZoom);
 
 	// create image with ImageDataProvider
 	image = new Image(display, imageDataProvider);
@@ -776,7 +789,7 @@ void getImageData_int(int zoom) {
 	boundsAtZoom = new Rectangle(0, 0, imageDataAtZoom.width, imageDataAtZoom.height);
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals(":d: Size of ImageData returned from Image.getImageData(int) method doesn't return matches with bounds in Pixel values.", scaleBounds(bounds, zoom, 100), boundsAtZoom);
+	assertEquals(scaleBounds(bounds, zoom, 100), boundsAtZoom);
 
 	// create image with ImageDataProvider that only has 1x data
 	image = new Image(display, imageDataProvider1xOnly);
@@ -784,7 +797,7 @@ void getImageData_int(int zoom) {
 	boundsAtZoom = new Rectangle(0, 0, imageDataAtZoom.width, imageDataAtZoom.height);
 	bounds = image.getBounds();
 	image.dispose();
-	assertEquals(":d: Size of ImageData returned from Image.getImageData(int) method doesn't return matches with bounds in Pixel values.", scaleBounds(bounds, zoom, 100), boundsAtZoom);
+	assertEquals(scaleBounds(bounds, zoom, 100), boundsAtZoom);
 }
 
 public static Rectangle scaleBounds (Rectangle rect, int targetZoom, int currentZoom) {
@@ -860,9 +873,8 @@ public void test_isDisposed() {
 
 @Test
 public void test_setBackgroundLorg_eclipse_swt_graphics_Color() {
-	assumeFalse(
-			"Excluded test_setBackgroundLorg_eclipse_swt_graphics_Color(org.eclipse.swt.tests.junit.Test_org_eclipse_swt_graphics_Image)",
-			SwtTestUtil.isGTK);
+	assumeFalse(SwtTestUtil.isGTK,
+			"Excluded test_setBackgroundLorg_eclipse_swt_graphics_Color(org.eclipse.swt.tests.junit.Test_org_eclipse_swt_graphics_Image)");
 	// TODO Fix GTK failure.
 	ImageGcDrawer noOpGcDrawer = (gc, width, height) -> {};
 	Image image1 = new Image(display, noOpGcDrawer, 10, 10);
@@ -891,7 +903,7 @@ public void test_setBackgroundLorg_eclipse_swt_graphics_Color() {
 	Image image4 = new Image(display, noOpGcDrawer, 10, 10);
 	image4.setBackground(display.getSystemColor(SWT.COLOR_GREEN));
 	Color color4 = image4.getBackground();
-	assertNull("background color should be null for non-transparent image", color4);
+	assertNull(color4);
 	image4.dispose();
 
 	// create an image with transparency and then set the background color
@@ -901,7 +913,7 @@ public void test_setBackgroundLorg_eclipse_swt_graphics_Color() {
 	Image image5 = new Image(display, imageData);
 	image5.setBackground(display.getSystemColor(SWT.COLOR_GREEN));
 	Color color5 = image5.getBackground();
-	assertEquals("background color should have been set to green", display.getSystemColor(SWT.COLOR_GREEN), color5);
+	assertEquals(display.getSystemColor(SWT.COLOR_GREEN), color5);
 	image5.dispose();
 }
 
@@ -920,18 +932,19 @@ public void test_toString() {
 /* custom */
 Display display;
 
-/** Test implementation **/
-
-void getImageData1() {
+@Test
+public void test_getImageData_fromFiles() {
+	int numFormats = SwtTestUtil.imageFormats.length;
 	String fileName = SwtTestUtil.imageFilenames[0];
-	for (String format : SwtTestUtil.imageFormats) {
+	for (int i=0; i<numFormats; i++) {
+		String format = SwtTestUtil.imageFormats[i];
 		try (InputStream stream = SwtTestUtil.class.getResourceAsStream(fileName + "." + format)) {
 			ImageData data1 = new ImageData(stream);
 			Image image = new Image(display, data1);
 			ImageData data2 = image.getImageData();
 			image.dispose();
-			assertEquals("Image width should be the same", data1.width, data2.width);
-			assertEquals("Image height should be the same", data1.height, data2.height);
+			assertEquals(data1.width, data2.width);
+			assertEquals(data1.height, data2.height);
 		} catch (IOException e) {
 			// continue;
 		}
@@ -942,31 +955,53 @@ void getImageData1() {
  * Verify Image.getImageData returns pixels with the same RGB value as the
  * source image. This test only makes sense with depth of 24 and 32 bits.
  */
-void getImageData2(int depth, PaletteData palette) {
+@Test
+public void test_getImageData_fromImageForCustomImageData() {
 	int width = 10;
 	int height = 10;
 	Color color = new Color(0, 0xff, 0);
-	RGB colorRGB = color.getRGB();
+	PaletteData palette = new PaletteData(0xff0000, 0xff00, 0xff);
+	int[] depths = new int[] { 24, 32 };
+	for (int depth : depths) {
+		ImageData imageData = new ImageData(width, height, depth, palette);
+		Image image = new Image(display, imageData);
+		fillImage(image, color);
+		ImageData newData = image.getImageData();
+		assertAllPixelsHaveColor(newData, color);
+		image.dispose();
+	}
+}
 
-	ImageData imageData = new ImageData(width, height, depth, palette);
-	Image image = new Image(display, imageData);
+@Test
+public void test_getImageData_fromImage() {
+	int width = 10;
+	int height = 10;
+	Color color = new Color(0, 0xff, 0);
+	Image image = new Image(display, width, height);
+	fillImage(image, color);
+	ImageData imageData = image.getImageData();
+	assertAllPixelsHaveColor(imageData, color);
+	image.dispose();
+}
 
+private static void fillImage(Image image, Color fillColor) {
 	GC gc = new GC(image);
-	gc.setBackground(color);
-	gc.setForeground(color);
-	gc.fillRectangle(0, 0, 10, 10);
+	gc.setBackground(fillColor);
+	gc.setForeground(fillColor);
+	gc.fillRectangle(image.getBounds());
+	gc.dispose();
+}
 
-	ImageData newData = image.getImageData();
-	PaletteData newPalette = newData.palette;
-	for (int i = 0; i < width; i++) {
-		for (int j = 0; j < height; j++) {
-			int pixel = newData.getPixel(i, j);
+private static PaletteData assertAllPixelsHaveColor(ImageData imageData, Color expectedColor) {
+	PaletteData newPalette = imageData.palette;
+	for (int x = 0; x < imageData.width; x++) {
+		for (int y = 0; y < imageData.height; y++) {
+			int pixel = imageData.getPixel(x, y);
 			RGB rgb = newPalette.getRGB(pixel);
-			assertTrue("rgb.equals(colorRGB)", rgb.equals(colorRGB));
+			assertEquals(expectedColor.getRGB(), rgb);
 		}
 	}
-	gc.dispose();
-	image.dispose();
+	return newPalette;
 }
 
 RGB getRealRGB(Color color) {
@@ -1036,11 +1071,11 @@ public void test_updateWidthHeightAfterDPIChange() {
 		Image baseImage = new Image(display, noOpGcDrawer, imageSize.width, imageSize.height);
 		GC gc = new GC(display);
 		gc.drawImage(baseImage, 10, 10);
-		assertEquals("Base image size differs unexpectedly", imageSize, baseImage.getBounds());
+		assertEquals(imageSize, baseImage.getBounds());
 
 		DPIUtil.setDeviceZoom(deviceZoom * 2);
 		gc.drawImage(baseImage, 10, 10);
-		assertEquals("Image size at 100% must always stay the same despite the zoom factor", imageSize, baseImage.getBounds());
+		assertEquals(imageSize, baseImage.getBounds());
 		gc.dispose();
 		baseImage.dispose();
 	} finally {
@@ -1050,7 +1085,7 @@ public void test_updateWidthHeightAfterDPIChange() {
 
 @Test
 public void test_imageDataIsCached() {
-	assumeTrue("On-demand image creation only implemented for Windows", SwtTestUtil.isWindows);
+	assumeTrue(SwtTestUtil.isWindows, "On-demand image creation only implemented for Windows");
 	String imagePath = getPath("collapseall.png");
 	AtomicInteger callCount = new AtomicInteger();
 	ImageFileNameProvider imageFileNameProvider = __ -> {
@@ -1058,16 +1093,20 @@ public void test_imageDataIsCached() {
 		return imagePath;
 	};
 	Image fileNameProviderImage = new Image(display, imageFileNameProvider);
-	callCount.set(0);
-	fileNameProviderImage.getImageData(100);
-	fileNameProviderImage.getImageData(100);
-	fileNameProviderImage.getImageData(100);
-	assertEquals(0, callCount.get());
+	try {
+		callCount.set(0);
+		fileNameProviderImage.getImageData(100);
+		fileNameProviderImage.getImageData(100);
+		fileNameProviderImage.getImageData(100);
+		assertEquals(0, callCount.get());
+	} finally {
+		fileNameProviderImage.dispose();
+	}
 }
 
 @Test
 public void test_imageDataSameViaDifferentProviders() {
-	assumeFalse("Cocoa generates inconsistent image data", SwtTestUtil.isCocoa);
+	assumeFalse(SwtTestUtil.isCocoa, "Cocoa generates inconsistent image data");
 	String imagePath = getPath("collapseall.png");
 	ImageFileNameProvider imageFileNameProvider = zoom -> {
 		return (zoom == 100) ? imagePath : null;
@@ -1093,7 +1132,7 @@ public void test_imageDataSameViaDifferentProviders() {
 
 @Test
 public void test_imageDataSameViaProviderAndSimpleData() {
-	assumeFalse("Cocoa generates inconsistent image data", SwtTestUtil.isCocoa);
+	assumeFalse(SwtTestUtil.isCocoa, "Cocoa generates inconsistent image data");
 	String imagePath = getPath("collapseall.png");
 	ImageFileNameProvider imageFileNameProvider = __ -> {
 		return imagePath;
@@ -1144,23 +1183,5 @@ public void test_gcOnImageGcDrawer_imageDataAtNonDeviceZoom() {
 	}
 }
 
-private Comparator<ImageData> imageDataComparator() {
-	return Comparator.<ImageData>comparingInt(d -> d.width) //
-			.thenComparing(d -> d.height) //
-			.thenComparing((ImageData firstData, ImageData secondData) -> {
-				for (int x = 0; x < firstData.width; x++) {
-					for (int y = 0; y < firstData.height; y++) {
-						if (firstData.getPixel(x, y) != secondData.getPixel(x, y)) {
-							return -1;
-						}
-						if (firstData.getAlpha(x, y) != secondData.getAlpha(x, y)) {
-							return -1;
-						}
-					}
-				}
-				return 0;
-			});
-}
-
 }
 
